==> jc-1.4.0.tar.gz: gnu/java/beans/decoder/VoidHandler.h <==
// public class gnu.java.beans.decoder.VoidHandler

// class file dependencies
// @dep_class 670cc122e6cfc20a gnu_java_beans_decoder_AbstractElementHandler
// @dep_class e3a8d5bc98088854 gnu_java_beans_decoder_VoidHandler
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_java_beans_decoder_AbstractElementHandler

#include "gnu/java/beans/decoder/AbstractElementHandler.h"

#ifndef _JC_gnu_java_beans_decoder_VoidHandler_H_
#define _JC_gnu_java_beans_decoder_VoidHandler_H_

// Forward structure declarations
struct _jc_gnu_java_beans_decoder_Context$object;
struct _jc_gnu_java_beans_decoder_ElementHandler$object;
struct _jc_java_beans_ExceptionListener$object;
struct _jc_java_lang_Class$object;
struct _jc_org_xml_sax_Attributes$object;

// Typedefs
typedef struct _jc_gnu_java_beans_decoder_VoidHandler$sub_refs	_jc_gnu_java_beans_decoder_VoidHandler$sub_refs;
typedef struct _jc_gnu_java_beans_decoder_VoidHandler$sub_nonrefs	_jc_gnu_java_beans_decoder_VoidHandler$sub_nonrefs;
typedef struct _jc_gnu_java_beans_decoder_VoidHandler$refs	_jc_gnu_java_beans_decoder_VoidHandler$refs;
typedef struct _jc_gnu_java_beans_decoder_VoidHandler$nonrefs	_jc_gnu_java_beans_decoder_VoidHandler$nonrefs;
typedef struct _jc_gnu_java_beans_decoder_VoidHandler$object	_jc_gnu_java_beans_decoder_VoidHandler$object;

typedef const struct _jc_gnu_java_beans_decoder_VoidHandler$vmethods	_jc_gnu_java_beans_decoder_VoidHandler$vmethods;
typedef const struct _jc_gnu_java_beans_decoder_VoidHandler$vtable	_jc_gnu_java_beans_decoder_VoidHandler$vtable;
typedef const struct _jc_gnu_java_beans_decoder_VoidHandler$vtype	_jc_gnu_java_beans_decoder_VoidHandler$vtype;

// Constructors
extern void _jc_gnu_java_beans_decoder_VoidHandler$method$_init$7d8397207e40a3b4(_jc_env *, struct _jc_gnu_java_beans_decoder_VoidHandler$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_object *_jc_gnu_java_beans_decoder_VoidHandler$method$startElement$c132d696183c1bce(_jc_env *, struct _jc_gnu_java_beans_decoder_VoidHandler$object *, struct _jc_object *, struct _jc_object *);
extern struct _jc_object *_jc_gnu_java_beans_decoder_VoidHandler$method$startElementImpl$1e68321eb469b8fc(_jc_env *, struct _jc_gnu_java_beans_decoder_VoidHandler$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_decoder_VoidHandler$method_info$startElement$c132d696183c1bce;
extern _jc_method _jc_gnu_java_beans_decoder_VoidHandler$method_info$startElementImpl$1e68321eb469b8fc;

// Virtual methods structure
struct _jc_gnu_java_beans_decoder_VoidHandler$vmethods {
	struct _jc_object	*(*startElement$c132d696183c1bce)(_jc_env *, struct _jc_gnu_java_beans_decoder_VoidHandler$object *, struct _jc_object *, struct _jc_object *);
	struct _jc_object	*(*startElementImpl$1e68321eb469b8fc)(_jc_env *, struct _jc_gnu_java_beans_decoder_VoidHandler$object *, struct _jc_object *);
};

// Vtable
struct _jc_gnu_java_beans_decoder_VoidHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_decoder_AbstractElementHandler$vmethods	gnu_java_beans_decoder_AbstractElementHandler;
	_jc_gnu_java_beans_decoder_VoidHandler$vmethods	gnu_java_beans_decoder_VoidHandler;
};

// Vtype
struct _jc_gnu_java_beans_decoder_VoidHandler$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_decoder_VoidHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_VoidHandler$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_decoder_VoidHandler$refs {
    _jc_gnu_java_beans_decoder_VoidHandler$sub_refs	gnu_java_beans_decoder_VoidHandler;
    _jc_gnu_java_beans_decoder_AbstractElementHandler$sub_refs	gnu_java_beans_decoder_AbstractElementHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_VoidHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_decoder_VoidHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_decoder_AbstractElementHandler$sub_nonrefs	gnu_java_beans_decoder_AbstractElementHandler;
    _jc_gnu_java_beans_decoder_VoidHandler$sub_nonrefs	gnu_java_beans_decoder_VoidHandler;
};

// Object instance structure
struct _jc_gnu_java_beans_decoder_VoidHandler$object {
	_jc_gnu_java_beans_decoder_VoidHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_decoder_VoidHandler$vtype	*vtype;
	_jc_gnu_java_beans_decoder_VoidHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_decoder_VoidHandler$vtype _jc_gnu_java_beans_decoder_VoidHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_decoder_VoidHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_decoder_VoidHandler$class_object;

#endif	/* _JC_gnu_java_beans_decoder_VoidHandler_H_ */

==> jc-1.4.6.tar.gz: gnu/java/beans/decoder/VoidHandler.h <==
// public class gnu.java.beans.decoder.VoidHandler

// class file dependencies
// @dep_class 670cc122e6cfc20a gnu_java_beans_decoder_AbstractElementHandler
// @dep_class e3a8d5bc98088854 gnu_java_beans_decoder_VoidHandler
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_java_beans_decoder_AbstractElementHandler

#include "gnu/java/beans/decoder/AbstractElementHandler.h"

#ifndef _JC_gnu_java_beans_decoder_VoidHandler_H_
#define _JC_gnu_java_beans_decoder_VoidHandler_H_

// Forward structure declarations
struct _jc_gnu_java_beans_decoder_Context$object;
struct _jc_gnu_java_beans_decoder_ElementHandler$object;
struct _jc_java_beans_ExceptionListener$object;
struct _jc_java_lang_Class$object;
struct _jc_org_xml_sax_Attributes$object;

// Typedefs
typedef struct _jc_gnu_java_beans_decoder_VoidHandler$sub_refs	_jc_gnu_java_beans_decoder_VoidHandler$sub_refs;
typedef struct _jc_gnu_java_beans_decoder_VoidHandler$sub_nonrefs	_jc_gnu_java_beans_decoder_VoidHandler$sub_nonrefs;
typedef struct _jc_gnu_java_beans_decoder_VoidHandler$refs	_jc_gnu_java_beans_decoder_VoidHandler$refs;
typedef struct _jc_gnu_java_beans_decoder_VoidHandler$nonrefs	_jc_gnu_java_beans_decoder_VoidHandler$nonrefs;
typedef struct _jc_gnu_java_beans_decoder_VoidHandler$object	_jc_gnu_java_beans_decoder_VoidHandler$object;

typedef const struct _jc_gnu_java_beans_decoder_VoidHandler$vmethods	_jc_gnu_java_beans_decoder_VoidHandler$vmethods;
typedef const struct _jc_gnu_java_beans_decoder_VoidHandler$vtable	_jc_gnu_java_beans_decoder_VoidHandler$vtable;
typedef const struct _jc_gnu_java_beans_decoder_VoidHandler$vtype	_jc_gnu_java_beans_decoder_VoidHandler$vtype;

// Constructors
extern void _jc_gnu_java_beans_decoder_VoidHandler$method$_init$7d8397207e40a3b4(_jc_env *, struct _jc_gnu_java_beans_decoder_VoidHandler$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_gnu_java_beans_decoder_VoidHandler$method$startElement$c132d696183c1bce(_jc_env *, struct _jc_gnu_java_beans_decoder_VoidHandler$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_java_beans_decoder_VoidHandler$method$startElementImpl$1e68321eb469b8fc(_jc_env *, struct _jc_gnu_java_beans_decoder_VoidHandler$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_decoder_VoidHandler$method_info$startElement$c132d696183c1bce;
extern _jc_method _jc_gnu_java_beans_decoder_VoidHandler$method_info$startElementImpl$1e68321eb469b8fc;

// Virtual methods structure
struct _jc_gnu_java_beans_decoder_VoidHandler$vmethods {
	struct _jc_object	*(*startElement$c132d696183c1bce)(_jc_env *, struct _jc_gnu_java_beans_decoder_VoidHandler$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*startElementImpl$1e68321eb469b8fc)(_jc_env *, struct _jc_gnu_java_beans_decoder_VoidHandler$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_beans_decoder_VoidHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_decoder_AbstractElementHandler$vmethods	gnu_java_beans_decoder_AbstractElementHandler;
	_jc_gnu_java_beans_decoder_VoidHandler$vmethods	gnu_java_beans_decoder_VoidHandler;
};

// Vtype
struct _jc_gnu_java_beans_decoder_VoidHandler$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_decoder_VoidHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_VoidHandler$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_decoder_VoidHandler$refs {
    _jc_gnu_java_beans_decoder_VoidHandler$sub_refs	gnu_java_beans_decoder_VoidHandler;
    _jc_gnu_java_beans_decoder_AbstractElementHandler$sub_refs	gnu_java_beans_decoder_AbstractElementHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_VoidHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_decoder_VoidHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_decoder_AbstractElementHandler$sub_nonrefs	gnu_java_beans_decoder_AbstractElementHandler;
    _jc_gnu_java_beans_decoder_VoidHandler$sub_nonrefs	gnu_java_beans_decoder_VoidHandler;
};

// Object instance structure
struct _jc_gnu_java_beans_decoder_VoidHandler$object {
	_jc_gnu_java_beans_decoder_VoidHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_decoder_VoidHandler$vtype	*vtype;
	_jc_gnu_java_beans_decoder_VoidHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_decoder_VoidHandler$vtype _jc_gnu_java_beans_decoder_VoidHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_decoder_VoidHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_decoder_VoidHandler$class_object;

#endif	/* _JC_gnu_java_beans_decoder_VoidHandler_H_ */
